#
# spec file for package boomaga
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           boomaga
Version:        3.0.0
Release:        3.19
Summary:        Virtual Printer for Viewing a Document before Printing
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          Productivity/Publishing/Other
URL:            https://www.boomaga.org/
Source0:        https://github.com/Boomaga/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
# SLE12 needs special BuildRequires.
# For suse_version values see https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
%if 0%{?suse_version} == 1315 && 0%{?is_opensuse} != 1
# For SLE12 by default CUPS 1.7.5 is provided and alternatively CUPS 1.5.4 is provided in the "legacy" module.
# For SLE12 build it with traditional CUPS 1.5.4 to ensure it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4
# because libcups and libcupsimage in CUPS 1.7.5 are backward compatible with CUPS 1.5.4 so that applications
# that have been built with CUPS 1.5.4 also work under CUPS 1.7.5 but the libraries in CUPS 1.7.5 provide
# some additional functions so that applications that have been built with CUPS 1.7.5 and use those
# additional functions would not work under CUPS 1.7.5.
# Only in the Printing project for SLE12 use cups154-ddk (a sub package of the cups154-SLE12 source package):
BuildRequires:  cups154
BuildRequires:  cups154-devel
%else
# Anything what is not SLE12 (i.e. SLE11 and all openSUSE versions) have "normal" BuildRequires:
BuildRequires:  cups
BuildRequires:  cups-devel
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  snappy-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(poppler) >= 0.18
BuildRequires:  pkgconfig(poppler-cpp)
BuildRequires:  pkgconfig(zlib)
Requires:       ghostscript
Requires(post): %{_sbindir}/lpadmin
Requires(postun): %{_sbindir}/lpadmin
Recommends:     %{name}-lang

%description
Boomaga (BOOklet MAnager) is a virtual printer for viewing a document
before printing it out using the physical printer.
Select the "Boomaga" printer in any program and the Boomaga window
opens in several seconds (CUPS takes some time to respond).
If you print out one more document, it gets added to the previous one,
and you can also print them out as one.
Regardless of whether your printer supports duplex printing or not, you
would be able to easily print on both sides of the sheet.

%lang_package

%prep
%setup -q

%build
%cmake \
    -DCUPS_PPD_DIR=%{_datadir}/cups/model/
make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install
%find_lang %{name} --with-qt
%suse_update_desktop_file -r %{name} Office Presentation

%post
if [ "$1" -eq 1 ] ; then
    %{_sbindir}/lpadmin -h localhost -p "Boomaga" -v "boomaga:/" -E -m "boomaga.ppd" -o printer-is-shared=no -o PageSize=A4
fi

%postun
if [ "$1" -eq 0 ] ; then
     %{_sbindir}/lpadmin -h localhost -x "Boomaga"
fi

%files
%license COPYING GPL LGPL
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/cups/model/*.ppd
%{_datadir}/dbus-1/services/org.boomaga.service
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_datadir}/mime/packages/%{name}.xml
%{_prefix}/lib/cups/backend/%{name}
%{_mandir}/man?/*

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/translations/

%changelog
* Wed Feb 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Require zlib explicitly
- Spec cleanup
- Remove obsolete macros in %%post/%%postun
- Switch to cmake() syntax for Qt requirements
* Tue Aug 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon Apr  8 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 3.0.0.
  * A new backend that works more reliably in modern distributions.
  * Added support for Wayland sessions.
  * Support for Postscript input files.
  * Simplification of the program structure, reduced the number of
    executable files.
  * Faster processing of large PDF files.
  * SELinux support.
  * Some GUI improvements.
  * Updated translations.
* Thu Apr 26 2018 lazy.kent@opensuse.org
- Update to 1.3.0.
  * Added support for RightToLeft page layouts.
  * Some GUI improvements.
  * Updated translations.
* Thu Apr  5 2018 lazy.kent@opensuse.org
- Update to 1.2.0.
  * Fix: The program shows empty page if page contents is a link to
    the array.
  * Fix In some cases, the program chose an incorrect value of the
    DISPLAY variable.
  * Fix: More accurate handling of comments in the file.
  * Updated translations.
* Fri Jan  5 2018 lazy.kent@opensuse.org
- Update to 1.1.0.
  * Fix: Sometimes the backend has incorrectly defined environment
    variables.
  * Fix in cmake: Allow to use system build flags.
  * Fix: Install correct values in boomaga.ppd.
  * Updated translations.
* Mon Dec 11 2017 lazy.kent@opensuse.org
- Update to 1.0.0.
  * Previously, the program used private methods from poppler.
    This caused a lot of problems. Now the program uses its own parser,
    written from scratch.
  * Add “Flip on long edge” and “Flip on short edge” options in
    the printer preferences dialog.
  * Improved display and print for some not quite correct PDF files.
  * Fix: typos.
  * Updated translations.
* Fri Jul 14 2017 lazy.kent@opensuse.org
- Build against Qt5 for SLE 12.
* Mon Jul 10 2017 lazy.kent@opensuse.org
- Update to 0.9.1.
  * Fix: When building with Qt5, the program creates incorrect
    directory for temporary files.
  * Fix: typos.
  * Updated translations.
- Build against Qt5 for Factory.
* Tue Apr  4 2017 lazy.kent@opensuse.org
- Update to 0.9.0.
  * Add grayscale printing option.
  * Add an option to print the multiple copies collated.
  * All functions of the program are now available via the main menu.
  * The program can automatically save your session.
  * Program allow to set negative margins on page.
  * Show current page number on the status bar.
  * Fixed Export to PDF function.
  * Updated translations.
  * Some GUI improvements.
  * Many small fixes.
* Mon Feb  6 2017 jengelh@inai.de
- Trim filler words from description
* Sun Oct  9 2016 lazy.kent@opensuse.org
- Update to 0.8.0.
  * You can see previews of all sub-booklets, and quickly switch of
    them.
  * Scrolling speed now depends on the mouse wheel speed.
  * Some GUI improvements.
  * Add shortcuts for prev. and next page view.
  * Fix: Sometimes the rendering of the page hides the frame.
  * Fix: Sometimes the program can not find a helper utility
    (boomagamerger).
  * Add ${LIB_SUFFIX} for installation at x86_64.
  * The CUPS backend was rewritten on C++. This eliminated the some
    problems, for example escaping characters.
  * Asynchronous processing of DBUS messages.
  * Updated translations.
- Change RPM Croup to Productivity/Publishing/Other.
* Sat Jun 27 2015 lazy.kent@opensuse.org
- Update to 0.7.1.
  * Clone job feature added.
  * Remove space before ellipsis.
  * Translations for "Clone job".
  * Support print count options of CUPS.
  * Print with options feature added.
  * Save geometry of PrinterDialog.
  * Added profiles for printer.
  * Save size of the PrinterSettingsDialog.
  * Crush when no printer found.
  * Escape quotes in job title passed to CUPS backend.
  * Fixed "Can't extract D-Bus bus address...".
* Fri Mar 20 2015 jsmeix@suse.de
- For SLE12 build it with traditional CUPS 1.5.4 to ensure
  it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4.
* Sat Nov 29 2014 lazy.kent@opensuse.org
- Update to 0.6.2.
  * Fix: Poppler broke API compatibility in 0.28.0.
- Drop boomaga-0.6.1-poppler_028.patch: fixed upstream.
- Correct the source URL.
* Sun Nov 23 2014 lazy.kent@opensuse.org
- Add boomaga-0.6.1-poppler_028.patch: fix compilation with poppler
  0.28.
* Sat Oct 18 2014 lazy.kent@opensuse.org
- Update to 0.6.1.
  * Fix: Sometimes the program did not show the contents of the
    pages.
* Sun Aug 31 2014 lazy.kent@opensuse.org
- Update to 0.6.0.
  * You can save and then load your piece of work.
  * Added desktop file and MIME associations for saved project
    files.
  * Added dag-and-drop support.
  * Added two layouts for the vertical placement of pages.
  * Added support for landscape documents.
  * You can rotate the entire job, or page individually.
  * Fixed wrong icon drawing for some icons themes.
  * You can split long document on booklets, manual or
    automatically.
  * Updated translations.
  * Many fixes.
- Add BuildRequires: hicolor-icon-theme, update-desktop-files.
- Add Requires(pre): shared-mime-info.
- Use %%suse_update_desktop_file macro. Add Category: Presentation.
- Use %%icon_theme_cache_post/un and %%mime_database_post/un macros.
* Fri Apr 11 2014 lazy.kent@opensuse.org
- Add back BuildRequires: libpoppler-cpp0. That fixes build against
  openSUSE standard repositories.
* Fri Apr  4 2014 lazy.kent@opensuse.org
- Update to 0.5.0.
  * Add ability to export to PDF.
  * Fill metadata title from the first job title.
  * Add German and Greek translations.
* Sat Mar 29 2014 lazy.kent@opensuse.org
- Don't use _service file.
- Use %%cmake macro.
* Fri Mar 14 2014 lazy.kent@opensuse.org
- Remove BuildRequires: libpoppler-cpp0 (fixed bnc#864299).
* Sun Feb 23 2014 lazy.kent@opensuse.org
- Update to 0.4.
  * No changelog provided.
- Add BuildRequires: pkgconfig(poppler-cpp); remove
  pkgconfig(poppler-qt4).
* Sun Dec 15 2013 lazy.kent@opensuse.org
- Initial package created - 0.3.
